==> open-xchange-guard-ui_2.8.0.orig.tar.bz2: open-xchange-guard-ui-2.8.0/oxguard-ui/apps/oxguard/mail/pubkey.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016-2020 OX Software GmbH
 */

define('oxguard/mail/pubkey', ['oxguard/core/og_http',
                               'gettext!oxguard'],
function (http, gt) {

    function getPubKeyAttachment () {
        var def = $.Deferred();
        var params = '&id=' + ox.user_id + '&cid=' + ox.context_id;
        http.get(ox.apiRoot, '/oxguard/pgpmail/public.asc?action=getkeybyid' + params)
        .done(function (data) {
            if (data === null) {
                def.reject(gt('Unable to get key'));
            }
            if (data.indexOf('BEGIN PGP') > -1) { // Verify PGP structure
                var attach = { // Attach the pgp data as attachment
                    content: data,
                    content_type: 'text/plain',
                    disp: 'attachment',
                    size: data.length,
                    filename: 'public.asc',
                    type: 'asc',
                    group: 'attachment',
                    guard: 'pubkey',
                    raw: true
                };
                def.resolve(attach);
            }
            def.reject();
        })
        .fail(function (data) {
            console.log(data);
            def.reject(gt('Unable to get key'));
        });
        return (def);
    }

    return {
        getPubKeyAttachment: getPubKeyAttachment
    };
});

==> open-xchange-guard-ui_2.10.1.orig.tar.bz2: open-xchange-guard-ui-2.10.1/oxguard-ui/apps/oxguard/mail/pubkey.js <==
/**
 * All content on this website (including text, images, source
 * code and any other original works), unless otherwise noted,
 * is licensed under a Creative Commons License.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016-2020 OX Software GmbH
 */

define('oxguard/mail/pubkey', ['oxguard/core/og_http',
                               'gettext!oxguard'],
function (http, gt) {

    function getPubKeyAttachment () {
        var def = $.Deferred();
        var params = '&keyType=public';
        http.simplePost(ox.apiRoot, '/oxguard/keys?action=downloadKey' + params)
        .done(function (data) {
            if (data === null) {
                def.reject(gt('Unable to get key'));
            }
            if (data.indexOf('BEGIN PGP') > -1) { // Verify PGP structure
                var attach = { // Attach the pgp data as attachment
                    content: data,
                    content_type: 'text/plain',
                    disp: 'attachment',
                    size: data.length,
                    filename: 'public.asc',
                    type: 'asc',
                    group: 'attachment',
                    guard: 'pubkey',
                    raw: true
                };
                def.resolve(attach);
            }
            def.reject();
        })
        .fail(function (data) {
            console.log(data);
            def.reject(gt('Unable to get key'));
        });
        return (def);
    }

    return {
        getPubKeyAttachment: getPubKeyAttachment
    };
});
